%%
%% This is file `jccmp.cls',
%% 
%% LaTeX2e Class file for commentaries of
%% Journal Club for Condensed Matter Physics
%% https://www.condmatjclub.org
%%
%% Prepared by Lijun Zhu
%% Send questions/comments to ljzhu@physics.ucr.edu
%% 
%% Version 1.1 2017/11/11 corrected website link
%% Version 1.2 2019/09/30 added DOI info
%%
\NeedsTeXFormat{LaTeX2e}[1996/12/01]%
\ProvidesClass{jccmp} [2019/09/30 version 1.2 ]% 

% This class extends the revtex4-1 class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass{article}

\RequirePackage{ifthen}
\RequirePackage[colorlinks,citecolor=black,linkcolor=black,filecolor=blue,urlcolor=blue]{hyperref}

\newcommand{\MONTH}{%
  \ifcase\the\month
  \or January% 1
  \or February% 2
  \or March% 3
  \or April% 4
  \or May% 5
  \or June% 6
  \or July% 7
  \or August% 8
  \or September% 9
  \or October% 10
  \or November% 11
  \or December% 12
  \fi}
  
\newcommand{\publishername}[1]{\def\@publishername{#1}}
\newcommand{\publishmonth}[1]{\def\@publishmonth{#1}}
\newcommand{\publishyear}[1]{\def\@publishyear{#1}}
\newcommand{\@publishsequence}{none}
\newcommand{\publishsequence}[1]{\def\@publishsequence{#1}}
\newcommand{\@doiindex}{none}
\newcommand{\doiindex}[1]{\def\@doiindex{#1}}
\newcommand{\@doilink}{none}
\newcommand{\doilink}[1]{\def\@doilink{#1}}

\publishername{Journal Club for Condensed Matter Physics\newline \url{https://www.condmatjclub.org}}
\publishmonth{\MONTH}
\publishyear{\the\year}
\doiindex{10.36471/JCCM\_\@publishmonth\_\@publishyear
     \ifthenelse{\equal{\@publishsequence}{none}}{\relax}
         {\_\@publishsequence}}
\doilink{10.36471/JCCM\_\@publishmonth_\@publishyear\_\@publishsequence}

\RequirePackage{xcolor}
\definecolor{slcolor}{HTML}{882B21}
\newcommand{\titlecolor}{\color{slcolor}}
\newcommand{\@affiliation}{none}
\newcommand{\affiliation}[1]{\def\@affiliation{#1}} 
\newcommand{\@authoropening}{Authors: }

\newenvironment{correspondent}
{\list{}{\rightmargin\leftmargin}\item\relax} {\endlist}

 
\newcommand{\@paperRecommended}{none}
\newcommand{\@paperRecommendedTwo}{none}
\newcommand{\@paperRecommendedThree}{none}
\newcommand{\@paperRecommendedFour}{none}
\newcommand{\@paperRecommendedFive}{none}
\newcommand{\@paperRecommendedSix}{none}
\newcommand{\@paperRecommendedSeven}{none}
\newcommand{\@paperRecommendedEight}{none}
\newcommand{\paperRecommended}[3]{\gdef\@paperRecommended{{\bfseries#1}\newline \@authoropening#2 \newline #3}}
\newcommand{\paperRecommendedTwo}[3]{\gdef\@paperRecommendedTwo{{\bfseries#1}\newline \@authoropening #2 \newline #3}}
\newcommand{\paperRecommendedThree}[3]{\gdef\@paperRecommendedThree{{\bfseries#1}\newline \@authoropening #2 \newline #3}}
\newcommand{\paperRecommendedFour}[3]{\gdef\@paperRecommendedFour{{\bfseries#1}\newline \@authoropening #2 \newline #3}}
\newcommand{\paperRecommendedFive}[3]{\gdef\@paperRecommendedFive{{\bfseries#1}\newline \@authoropening #2 \newline #3}}
\newcommand{\paperRecommendedSix}[3]{\gdef\@paperRecommendedSix{{\bfseries#1}\newline \@authoropening #2 \newline #3}}
\newcommand{\paperRecommendedSeven}[3]{\gdef\@paperRecommendedSeven{{\bfseries#1}\newline \@authoropening #2 \newline #3}}
\newcommand{\paperRecommendedEight}[3]{\gdef\@paperRecommendedEight{{\bfseries#1}\newline \@authoropening #2 \newline #3}}
 
\renewcommand*{\thefootnote}{\fnsymbol{footnote}}

\renewcommand\maketitle{%
  \newpage
  \null
   \vskip 1em%
   \begin{flushleft}
   {\fontfamily{phv}\fontseries{b}%
    \selectfont\LARGE \titlecolor \@title \par}%
    \vskip 1.5em%
    \ifthenelse{\equal{\@paperRecommendedTwo}{none}}
    	 {%only one paper
    	 \begin{enumerate}
         \item[] \@paperRecommended
         \end{enumerate}
         } %only one paper
         {% two or more papers 
         \mbox{}\begin{enumerate}
             \item {\@paperRecommended}
             \item {\@paperRecommendedTwo}
             \ifthenelse{\equal{\@paperRecommendedThree}{none}}{\relax}
                {\item \@paperRecommendedThree} % optional
             \ifthenelse{\equal{\@paperRecommendedFour}{none}}{\relax}
                {\item \@paperRecommendedFour} % optional
             \ifthenelse{\equal{\@paperRecommendedFive}{none}}{\relax}
                {\item \@paperRecommendedFive} % optional
             \ifthenelse{\equal{\@paperRecommendedSix}{none}}{\relax}
                {\item \@paperRecommendedSix} % optional
             \ifthenelse{\equal{\@paperRecommendedSeven}{none}}{\relax}
                {\item \@paperRecommendedSeven} % optional
             \ifthenelse{\equal{\@paperRecommendedEight}{none}}{\relax}
                {\item \@paperRecommendedEight} % optional
          \end{enumerate}
          }% two or more papers
    \vskip 1em
     {\large\slshape
     %\lineskip .75em%
    \begin{correspondent}
      Recommended with a Commentary by  \@author 
      \ifthenelse{\equal{\@affiliation}{none}}{\relax}
             {, \@affiliation} 
     \end{correspondent}
    \par}
 \end{flushleft}
   \vskip 2em
}%
 
 %
\RequirePackage[left=1in,right=1in,top=1in,bottom=1in]{geometry}
 
\RequirePackage{fancyhdr}
\fancypagestyle{firstpage}{%
\fancyhf{} % clear all six fields
\fancyhead[L]{\@publishername}
\fancyhead[R]{%
	\href{https://doi.org/\@doilink}{\color{black}{DOI:\@doiindex}}%
	\\
	}
\fancyfoot[C]{\thepage}
\renewcommand{\headrulewidth}{1pt}
\renewcommand{\footrulewidth}{0pt}
}
\fancypagestyle{followingpage}{%
\fancyhf{} % clear all six fields
\fancyfoot[C]{\thepage}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
}
\pagestyle{followingpage}
\AtBeginDocument{\thispagestyle{firstpage}}

